@@ -28,11 +28,7 @@
 #include <qlayout.h>
 #include <qregexp.h>
 #include <qstring.h>
-#if QT_VERSION >= 0x030100
-    #include <ktextedit.h>
-#else
-    #include <qtextedit.h>
-#endif
+#include <ktextedit.h>
 
 // KDE includes
 #include <kiconloader.h>
@@ -141,11 +137,8 @@ BarcodeWidget::BarcodeWidget(QWidget *parent, const char *name )
     connect( data, SIGNAL( textChanged( const QString & ) ), this, SLOT( slotValidateValue() ) );
     grid->addMultiCellWidget( data, 2, 2, 1, 3 );
 
-#if QT_VERSION >= 0x030100
-        multi = new KTextEdit( this );
-#else
-        multi = new QTextEdit( this );
-#endif
+    multi = new KTextEdit( this );
+
     multi->setTextFormat( QTextEdit::PlainText );
     multi->setWordWrap( QTextEdit::NoWrap );
     multi->setEnabled( false );
