@@ -25,7 +25,7 @@
 #include "barkode.h"
 
 /** A validator that takes to QRegExp's to check
- *  wether a barcode is valid or not.
+ *  whether a barcode is valid or not.
  */
 class BarcodeValidator : public QValidator {
  public:
@@ -66,11 +66,7 @@ class BarcodeCombo : public KComboBox  {
 class KIntNumInput;
 class KLineEdit;
 class KPushButton;
-#if QT_VERSION >= 0x030100
-    class KTextEdit;
-#else
-    class QTextEdit;
-#endif
+class KTextEdit;
 class QCheckBox;
 class QLabel;
 
@@ -112,12 +108,7 @@ class BarcodeWidget : public QWidget {
         KLineEdit* data;
         BarcodeValidator m_validator;
 
-#if QT_VERSION >= 0x030100
         KTextEdit* multi;
-#else
-        QTextEdit* multi;
-#endif
-        
         KIntNumInput* spinMargin;
         KIntNumInput* spinScale;
         KIntNumInput* spinRotation;
