@@ -208,11 +208,7 @@ void BarCodeDialog::copy()
     DocumentItemDrag* drag = new DocumentItemDrag();
     drag->setDocumentItem( &list );
 
-#if QT_VERSION >= 0x030100
     kapp->clipboard()->setData( drag, QClipboard::Clipboard );
-#else
-    kapp->clipboard()->setData( drag );
-#endif
 }
 
 #include "barcodedialog.moc"
