@@ -224,11 +224,7 @@ void TBarcodeDlg::setData( Barkode* b )
         QMap<QString,int>::Iterator it;
         for ( it = map.begin(); it != map.end(); ++it ) {
             if( it.data() == options->checksum() ) {
-                for( int i = 0; i < comboCheckSum->count(); i++ )
-                    if( comboCheckSum->text( i ) == it.key() ) {
-                        comboCheckSum->setCurrentItem( i );
-                        break;
-                    }
+                comboCheckSum->setCurrentItem(it.key());
                 break;
             }
         }
