@@ -281,18 +281,18 @@ void BatchPrinter::startImages()
     QPixmap pixmap( (int)measure.width( parent ), (int)measure.height( parent ) );
     while( (l = initLabel( &number ) ) != NULL )
     {
-        pixmap.fill( Qt::white );
-        painter->begin( &pixmap );
-        l->draw( painter, 0, 0 );
-        l->setIndex( number );
-        l->setRow( 0 );
-        l->setCol( 0 );
-
-        painter->end();
-
         for( int i = 0; i < number; i++ ) 
 	{
-	    QString name = m_path + "/";
+            pixmap.fill( Qt::white );
+            painter->begin( &pixmap );
+            l->setIndex( i );
+            l->setRow( 0 );
+            l->setCol( 0 );
+            l->draw( painter, 0, 0 );
+
+            painter->end();
+
+            QString name = m_path + "/";
 	    if( m_image_filename == E_ARTICLE )
 		name += m_data ? (*m_data)[m_cur_data_count].article_no : QString::number( m_cur_data_count );
 	    else if( m_image_filename == E_BARCODE )
@@ -318,6 +318,7 @@ void BatchPrinter::startImages()
                 return;
 	    }
         }
+
 	delete l;
     }
 
