@@ -968,11 +968,7 @@ void BatchWizard::loadData( const QString & data )
     }
 
     if( !dropped.isEmpty() )
-#if QT_VERSION >= 0x030100
         KMessageBox::informationList( this, i18n("<qt>The following items can not be added:" )+ "</qt>", dropped );
-#else
-        KMessageBox::questionYesNoList( this, i18n("<qt>The following items can not be added:" )+ "</qt>", dropped );
-#endif
 
     enableControls();
 }
