@@ -65,8 +65,7 @@ CommandUtils::CommandUtils(TCanvasItem* item)
 
 CommandUtils::~CommandUtils()
 {
-    if( m_canvas_item->remRef() == 0 )
-	delete m_canvas_item;
+    m_canvas_item->remRef();
 }
 
 bool CommandUtils::canvasHasItem()
@@ -109,8 +108,7 @@ NewItemCommand::NewItemCommand( MyCanvasView* view, const QString & name )
 
 NewItemCommand::~NewItemCommand()
 {
-    if( m_item->remRef() == 0 )
-	delete m_item;
+    m_item->remRef();
 }
 
 void NewItemCommand::execute()
@@ -119,7 +117,7 @@ void NewItemCommand::execute()
     {
         create();
 
-        if( m_object )    
+        if( m_object )
         {
             m_item = new TCanvasItem( cv );
             m_item->setItem( m_object );
