@@ -18,18 +18,23 @@
 #ifndef DEFINITION_H
 #define DEFINITION_H
 
+#include "measurements.h"
 #include "labelutils.h"
 #include <qmap.h>
 #include <qstring.h>
 
-#define I2S(x) QString::number(x)
+#ifndef I2S
+    #define I2S(x) QString::number(x)
+#endif // I2S
 
+class QWidget;
 class QFile;
 class QPaintDevice;
 class QString;
 class QStringList;
 class QSqlQuery;
 class Measurements;
+class QProgressDialog;
 /** @short A label definition;
   *
   * Represents a label definition. The definition is either read from
@@ -41,19 +46,18 @@ class Measurements;
   */
 class Definition : private LabelUtils {
     public:
-        Definition();
-        Definition( int label_def_id );
-        Definition( const QString & label_def_id );
-        Definition( const QString & producer, const QString & type );
+        Definition( QWidget* parent = 0 );
+        Definition( int label_def_id, QWidget* parent = 0 );
+        Definition( const QString & label_def_id, QWidget* parent = 0 );
+        Definition( const QString & producer, const QString & type, QWidget* parent = 0 );
         ~Definition();
 
         void setId( const QString & label_def_id );
         void setId( int label_def_id );
 
-        // never delete measurements!
-        Measurements* getMeasurements() const;
+        const Measurements & getMeasurements() const;
 
-        static int write( Measurements* c, QString type, QString producer );
+        static int write( const Measurements & c, QString type, QString producer );
         static int getClosest( const QString & producer, const QString & type );
         
         static const QStringList getProducers();
@@ -70,9 +74,12 @@ class Definition : private LabelUtils {
     private:
         void init( const QString & label_def_id );
         void getFileMeasurements( const QString & label_def_id );
+	static void initProgress();
+	static void increaseProgress();
+	static void destroyProgress();
 
-        static int writeSQL( Measurements* c, QString type, QString producer );
-        static int writeFile( Measurements* c, QString type, QString producer );
+        static int writeSQL( const Measurements & c, QString type, QString producer );
+        static int writeFile( const Measurements & c, QString type, QString producer );
         
         static bool showFileError();
         static bool openFile();
@@ -80,11 +87,13 @@ class Definition : private LabelUtils {
         static QMap<QString,QStringList> mapTypes;
         static QFile* file;
         static QByteArray* array;
+	static QProgressDialog* m_progress;
 
+	QWidget* m_parent;
         int id;
         QString producer;
         QString type;
-        Measurements* m;
+        Measurements m_measure;
         bool locked;
         static bool nodefmsg;
 };
