@@ -30,13 +30,12 @@
 // KDE includes
 #include <klocale.h>
 
-#define I2S(x) QString("%1").arg(x)
 LabelPreview::LabelPreview( QWidget* parent, const char* name )
     : QWidget( parent, name)
 {
     // For old DIN A4 preview
     PrinterSettings* ps = PrinterSettings::getInstance();
-    setFixedSize( QSize(  (int)ps->pageWidth() + 20, (int)ps->pageHeight() + 20 ) );
+    setFixedSize( QSize(  ((int)ps->pageWidth() + 20)/2, ((int)ps->pageHeight() + 20)/2 ) );
     m_prv_enabled = true;
 }
 
@@ -50,8 +49,8 @@ void LabelPreview::paintEvent( QPaintEvent* )
     p.setPen( QPen( Qt::black ) );
     p.translate( 10, 10 );
 
-    p.fillRect( 0, 0, 210, 297, QBrush( Qt::gray ) );
-    p.drawRect( 0, 0, 210, 297 );
+    p.fillRect( 0, 0, 210/2, 297/2, QBrush( Qt::gray ) );
+    p.drawRect( 0, 0, 210/2, 297/2 );
 
     if(!m_prv_enabled)
         return;
@@ -64,13 +63,13 @@ void LabelPreview::paintEvent( QPaintEvent* )
             else
                 p.setPen( QPen( Qt::black ) );
 
-            p.fillRect( int(measure.gapLeftMM() + (measure.gapHMM() * h)),
-                        int(measure.gapTopMM() + (measure.gapVMM() * v)),
-                        (int)measure.widthMM(), (int)measure.heightMM(), QBrush( Qt::white ) );
+            p.fillRect( int(measure.gapLeftMM() + (measure.gapHMM() * h)) / 2,
+                        int(measure.gapTopMM() + (measure.gapVMM() * v)) / 2 ,
+                        (int)measure.widthMM() / 2 , (int)measure.heightMM() / 2, QBrush( Qt::white ) );
 
-            p.drawRect( int(measure.gapLeftMM() + (measure.gapHMM() * h)),
-                        int(measure.gapTopMM() + (measure.gapVMM() * v)),
-                        (int)measure.widthMM(), (int)measure.heightMM() );
+            p.drawRect( int(measure.gapLeftMM() + (measure.gapHMM() * h)) / 2,
+                        int(measure.gapTopMM() + (measure.gapVMM() * v)) / 2,
+                        (int)measure.widthMM() / 2, (int)measure.heightMM() / 2 );
         }
     }
 }
@@ -264,40 +263,41 @@ void DefinitionDialog::updateType()
     comboType->insertItem( i18n( "Custom" ), 0 );
 }
 
-Measurements* DefinitionDialog::getCurrentMeasure()
+const Measurements DefinitionDialog::getCurrentMeasure()
 {
-    Measurements* m = new Measurements();
-    m->setGapLeft( editLGap->text().toDouble() );
-    m->setGapTop( editTGap->text().toDouble() );
-    m->setWidth( editWidth->text().toDouble() );
-    m->setHeight( editHeight->text().toDouble() );
-    m->setGapV( editVGap->text().toDouble() );
-    m->setGapH( editHGap->text().toDouble() );
-    m->setNumH( editNumH->text().toInt() );
-    m->setNumV( editNumV->text().toInt() );
+    Measurements m;
+    m.setGapLeft( editLGap->text().toDouble() );
+    m.setGapTop( editTGap->text().toDouble() );
+    m.setWidth( editWidth->text().toDouble() );
+    m.setHeight( editHeight->text().toDouble() );
+    m.setGapV( editVGap->text().toDouble() );
+    m.setGapH( editHGap->text().toDouble() );
+    m.setNumH( editNumH->text().toInt() );
+    m.setNumV( editNumV->text().toInt() );
 
     return m;
 }
 
 void DefinitionDialog::updateText()
 {
-    Definition d( comboProducer->currentText(), comboType->currentText() );
-    Measurements* m = d.getMeasurements();
-    editTGap->setText( I2S( m->gapTop() ) );
-    editLGap->setText( I2S( m->gapLeft() ) );
-    editWidth->setText( I2S( m->width() ) );
-    editHeight->setText( I2S( m->height() ) );
-    editVGap->setText( I2S( m->gapV() ) );
-    editHGap->setText( I2S( m->gapH() ) );
-    editNumH->setText( I2S( m->numH() ) );
-    editNumV->setText( I2S( m->numV() ) );
+    Definition   d( comboProducer->currentText(), comboType->currentText() );
+    Measurements m = d.getMeasurements();
+
+    editTGap->setText( I2S( m.gapTop() ) );
+    editLGap->setText( I2S( m.gapLeft() ) );
+    editWidth->setText( I2S( m.width() ) );
+    editHeight->setText( I2S( m.height() ) );
+    editVGap->setText( I2S( m.gapV() ) );
+    editHGap->setText( I2S( m.gapH() ) );
+    editNumH->setText( I2S( m.numH() ) );
+    editNumV->setText( I2S( m.numV() ) );
 
     updatePreview();
 }
 
 void DefinitionDialog::updatePreview()
 {
-    Measurements* m = getCurrentMeasure();
+    Measurements m = getCurrentMeasure();
 
     editHeight->setPaletteForegroundColor( Qt::black );
     editWidth->setPaletteForegroundColor( Qt::black );
@@ -309,31 +309,31 @@ void DefinitionDialog::updatePreview()
     editNumV->setPaletteForegroundColor( Qt::black );
     
     // Mark errors in Red
-    if( m->heightMM() > PrinterSettings::getInstance()->pageHeight() )
+    if( m.heightMM() > PrinterSettings::getInstance()->pageHeight() )
         editHeight->setPaletteForegroundColor( Qt::red );
 
-    if( m->widthMM() > PrinterSettings::getInstance()->pageWidth() )
+    if( m.widthMM() > PrinterSettings::getInstance()->pageWidth() )
         editWidth->setPaletteForegroundColor( Qt::red );
 
-    if( m->gapVMM() < m->heightMM() )
+    if( m.gapVMM() < m.heightMM() )
         editVGap->setPaletteForegroundColor( Qt::red );
 
-    if( m->gapHMM() < m->widthMM() )
+    if( m.gapHMM() < m.widthMM() )
         editHGap->setPaletteForegroundColor( Qt::red );
 
-    if( m->gapTopMM() >  PrinterSettings::getInstance()->pageHeight() - m->heightMM() )
+    if( m.gapTopMM() >  PrinterSettings::getInstance()->pageHeight() - m.heightMM() )
         editTGap->setPaletteForegroundColor( Qt::red );
 
-    if( m->gapLeftMM() > PrinterSettings::getInstance()->pageWidth() - m->widthMM() )
+    if( m.gapLeftMM() > PrinterSettings::getInstance()->pageWidth() - m.widthMM() )
         editLGap->setPaletteForegroundColor( Qt::red );
 
-    if( m->gapLeftMM() + m->numH() * m->gapHMM() > PrinterSettings::getInstance()->pageWidth() )
+    if( m.gapLeftMM() + m.numH() * m.gapHMM() > PrinterSettings::getInstance()->pageWidth() )
         editNumH->setPaletteForegroundColor( Qt::red );
 
-    if( m->gapTopMM() + m->numV() * m->gapVMM() > PrinterSettings::getInstance()->pageHeight() )
+    if( m.gapTopMM() + m.numV() * m.gapVMM() > PrinterSettings::getInstance()->pageHeight() )
         editNumV->setPaletteForegroundColor( Qt::red );
 
-    preview->setRect( QRect( (int)m->gapLeftMM(), (int)m->gapTopMM(), (int)m->widthMM(), (int)m->heightMM() ) );
+    preview->setRect( QRect( (int)m.gapLeftMM(), (int)m.gapTopMM(), (int)m.widthMM(), (int)m.heightMM() ) );
     preview->setMeasurements( m );
     preview->repaint();
 }
@@ -424,3 +424,5 @@ void DefinitionDialog::toggleExtension()
         showExtension( true );
 }
 
+
+#include "definitiondialog.moc"
