@@ -26,7 +26,7 @@ class LabelPreview : public QWidget {
         ~LabelPreview();
 
         void setRect( QRect label ) { size = label; }
-        void setMeasurements( Measurements* m ) { measure = (*m); }
+        void setMeasurements( const Measurements & m ) { measure = m; }
         
         void setPrvEnabled( bool b ) { m_prv_enabled = b; }
 
@@ -49,7 +49,7 @@ public:
     DefinitionDialog( QWidget* parent = 0, const char* name = 0, bool modal = true, WFlags fl = 0 );
     ~DefinitionDialog();
 private:
-    Measurements* getCurrentMeasure();
+    const Measurements getCurrentMeasure();
 
 private slots:
     void add();
