@@ -20,7 +20,6 @@
 #include "confwizard.h"
 #include "printersettings.h"
 #include "kbarcodesettings.h"
-#include "kactionmap.h"
 #include "barkode.h"
 
 // Qt includes
@@ -68,11 +67,13 @@ void DSMainWindow::setupActions()
 {
     KAction* quitAct = KStdAction::quit(kapp, SLOT(quit()), actionCollection());
     KAction* closeAct = KStdAction::close( this, SLOT( close() ), actionCollection(), "close" );
-    KAction* configureAct = KStdAction::preferences( KBarcodeSettings::getInstance(), SLOT(configure()), actionCollection() );
+    KAction* configureAct = KStdAction::preferences( KBarcodeSettings::getInstance(),
+            SLOT(configure()), actionCollection() );
     KAction* wizardAct = new KAction( i18n("&Start Configuration Wizard..."), BarIcon("wizard"), 0, this,
-                                SLOT(wizard()), actionCollection(), "wizard" );
-    connectAct = new KAction(i18n("&Connect to Database"), BarIcon("connect_no"), 0, this, SLOT(connectMySQL()),
-                                actionCollection(),"connect" );
+            SLOT(wizard()), actionCollection(), "wizard" );
+
+    connectAct = new KAction(i18n("&Connect to Database"), BarIcon("connect_no"), 0,
+                             this, SLOT(connectMySQL()), actionCollection(),"connect" );
 
 
     KAction* newTablesAct = new KAction( i18n("&Create Tables"), "", 0, this,
@@ -91,13 +92,11 @@ void DSMainWindow::setupActions()
     hlpMenu->removeItem( helpid );
     hlpMenu->insertItem( SmallIconSet("contents"), i18n("&Help"),
         this, SLOT(appHelpActivated()), Key_F1, -1, 0 );
-    hlpMenu->insertSeparator(-1);
-    hlpMenu->insertItem( i18n("&Action Map..."), this, SLOT( slotFunctionMap() ), 0, -1, 0 );
-    hlpMenu->insertSeparator(-2);
-    hlpMenu->insertItem( SmallIconSet("system"), i18n("&System Check..."), this, SLOT(showCheck() ), 0, -1, 0 );
-    hlpMenu->insertItem( SmallIconSet("barcode"), i18n("&Barcode Help..."), this, SLOT( startInfo() ), 0, -1, 0 );
-    hlpMenu->insertItem( i18n("&Donate..."), this, SLOT( donations() ), 0, -1, 0 );
-
+    hlpMenu->insertItem( SmallIconSet("barcode"), i18n("&Barcode Help..."), this, SLOT( startInfo() ), 0, -1, 1 );
+    hlpMenu->insertSeparator(3);
+    hlpMenu->insertItem( i18n("&Donate..."), this, SLOT( donations() ), 0, -1, 4 );
+    hlpMenu->insertSeparator(5);
+    hlpMenu->insertItem( SmallIconSet("system"), i18n("&System Check..."), this, SLOT(showCheck() ), 0, -1, 6 );
     menuBar()->insertItem( i18n("&File"), file );
     menuBar()->insertItem( i18n("&Settings"), settings );
     menuBar()->insertItem( i18n("&Help"), hlpMenu );
@@ -207,7 +206,6 @@ bool DSMainWindow::newTables()
 
 void DSMainWindow::donations()
 {
-    // orig =https://www.paypal.com/xclick/business=domseichter%40web.de&item_name=Support+KBarcode+Development&item_number=0&image_url=http%3A//www.kbarcode.net/themes/DeepBlue/images/logo.gif&no_shipping=1&return=http%3A//www.kbarcode.net&cancel_return=http%3A//www.kbarcode.net&cn=Suggestions%2C+Comments%3F&tax=0&currency_code=EUR
     QString url = "https://www.paypal.com/xclick/business=domseichter@web.de&item_name=Support+KBarcode+Development&item_number=0&image_url=www.kbarcode.net/themes/DeepBlue/images/logo.gif&no_shipping=1&return=www.kbarcode.net&cancel_return=www.kbarcode.net&cn=Suggestions,+Comments,&tax=0&currency_code=EUR";
     
     KMessageBox::information( this, i18n(
@@ -260,9 +258,4 @@ QString DSMainWindow::systemCheck()
     return text;
 }
 
-void DSMainWindow::slotFunctionMap()
-{
-    new KActionMapDlg( actionCollection(), this );
-}
-
 #include "dsmainwindow.moc"
