@@ -20,7 +20,7 @@
 #include <qregexp.h>
 
 DSTextEdit::DSTextEdit( QWidget* parent, const char* name )
-    : TextEditBase( parent, name )
+    : KTextEdit( parent, name )
 {
     connect( this, SIGNAL( textChanged() ), this, SLOT( fixParagraphs() ) );
 }
