@@ -25,13 +25,14 @@
 #include "definition.h"
 #include "tokenprovider.h"
 
-struct barcodeData;
 class BarCode;
+class Barkode;
 class QDomDocument;
 class QIODevice;
 class QString;
 class QPainter;
 class QPaintDevice;
+class QTextStream;
 class KPrinter;
 /** Creates a QPicture from the XML KBarcode file. If a SQL connections is available
   * the data from the SQL tables will be used, too.
@@ -39,28 +40,36 @@ class KPrinter;
 class Label : private LabelUtils, private XMLUtils, public TokenProvider {
     public:
         Label( Definition* _def, QIODevice* device, QString labelname, QPaintDevice* _printer, QString customer_id, QString _article_no, QString _group = "" );
+        Label( Definition* _def, QIODevice* device, QString labelname, QPaintDevice* _printer );
         ~Label();
 
-        QPicture* picture();
+        void epcl( QTextStream* stream );
+        void ipl( QTextStream* stream );
+        void zpl( QTextStream* stream );
+
+        void draw( QPainter* painter,int x, int y );
         
         int getId() const;  
         static void getXLabel( double x, double y, double width, double height, QPainter* painter, int mode, QString value = "" );
 
-        void setPrinter( KPrinter* p ) { m_printer = p; }
-        
+        //void setPrinter( KPrinter* p ) { m_printer = p; }
+
+	/** reimplemented from TokenProvider
+	 *  returns wether this label has to be regenerated everytime
+	 */
+	bool update();
+
     private:
-        void draw();
         void load( QIODevice* device );
-        void setBarcodeValue( barcodeData* data );
-        int getHighestZ();
-        int getLowestZ();
+        void setBarcodeValue( Barkode* barcode );
+        void InitBarcodes();
+        bool drawThisItem( const DocumentItem* item );
 
     protected:
-        QDomDocument* doc;
-
+        DocumentItemList m_list;
+        
         Definition* d;
-        QPicture p;
-        KPrinter* m_printer;
+        QPaintDevice* m_printer;
 
         bool m_sequence;
 };
