@@ -75,9 +75,6 @@
 #include <qtooltip.h>
 #include <qvalidator.h>
 #include <qxml.h>
-#if QT_VERSION <= 0x030100
-    #include <qregexp.h>
-#endif
 
 // KDE includes
 #include <kabc/stdaddressbook.h>
@@ -981,11 +978,7 @@ void LabelEditor::copy()
 
     DocumentItemDrag* drag = new DocumentItemDrag();
     drag->setDocumentItem( &items );
-#if QT_VERSION >= 0x030100
     kapp->clipboard()->setData( drag, QClipboard::Clipboard );
-#else
-    kapp->clipboard()->setData( drag );
-#endif
 }
 
 void LabelEditor::paste()
