@@ -18,7 +18,8 @@
 #ifndef MULTILINEEDITDLG_H
 #define MULTILINEEDITDLG_H
 
-#include <kdialogbase.h>
+#include <qwidget.h>
+#include "documentitem.h"
 
 class KActionCollection;
 class KToggleAction;
@@ -27,22 +28,17 @@ class KFontSizeAction;
 class KToolBar;
 class KSpell;
 class KSpellConfig;
-class KComboBox;
+class DSTextEdit;
+class TokenProvider;
 
-#if QT_VERSION >= 0x030100
-    class KTextEdit;
-#else
-    class QTextEdit;
-#endif
-class MultiLineEditDlg : public KDialogBase  {
+class MultiLineEditor : public QWidget {
     Q_OBJECT
     public:
-        MultiLineEditDlg( QString text, QWidget *parent=0, const char *name=0);
-        ~MultiLineEditDlg();
+        MultiLineEditor( TokenProvider* token, QWidget *parent=0, const char *name=0);
+        ~MultiLineEditor();
         QString text();
-
-        static QString getText( QString text, bool* ok, QWidget* parent = 0 );
-
+        void setText( const QString & t );
+        
     private slots:
         void setupActions();
         void updateActions();
@@ -58,14 +54,12 @@ class MultiLineEditDlg : public KDialogBase  {
         void setAlignRight( bool yes );
         void setAlignCenter( bool yes );
         void setAlignJustify( bool yes );               
-        void insertNewField(int index);
+        void insertNewField();
         
     protected:
-#if QT_VERSION >= 0x030100
-        KTextEdit* editor;
-#else
-        QTextEdit* editor;
-#endif
+        TokenProvider* m_token;
+
+	DSTextEdit* editor;
         
         KActionCollection* ac;
         
@@ -81,8 +75,6 @@ class MultiLineEditDlg : public KDialogBase  {
         KToggleAction *action_align_center;
         KToggleAction *action_align_justify;
 
-        KComboBox *action_insert_field ;
-
         KToolBar* toolBar;
         KToolBar* tool2Bar;
         KToolBar* tool3Bar;
