@@ -19,6 +19,13 @@
 #define MYCANVASVIEW_H
 
 #include <qcanvas.h>
+#include <qvaluelist.h>
+#include "documentitem.h"
+
+class TCanvasItem;
+
+typedef QValueList<TCanvasItem*> TCanvasItemList;
+
 
 class QRect;
 class QPainter;
@@ -59,7 +66,6 @@ class KCommandHistory;
 class KMacroCommand;
 class KRuler;
 class KStatusBar;
-class MyCanvasRectangle;
 class MyCanvasView : public QCanvasView
 {
     Q_OBJECT
@@ -75,16 +81,20 @@ class MyCanvasView : public QCanvasView
         BottomRight,
         Inside,
         Outside,
-        Barcode,
-        LineLeft,
-        LineRight
+        Barcode
     };
     
     public:
         MyCanvasView( Definition* d, MyCanvas *c, QWidget* parent=0, const char* name=0, WFlags f=0);
         ~MyCanvasView();
 
-        MyCanvasRectangle* getActive();
+	/** return a list of all DocumentItems on the canvas
+	 */
+	DocumentItemList getAllItems();
+
+        TCanvasItemList getSelected();
+
+        TCanvasItem* getActive();
         void setActive( QCanvasItem* item = 0, bool control = false );
 
         void setCurrent( QCanvasItem* item );
@@ -106,9 +116,12 @@ class MyCanvasView : public QCanvasView
         static int getLowestZ( QCanvasItemList list );
         static int getHighestZ( QCanvasItemList list );
         
-        void snapPoint(QPoint *point) ;
+        void snapPoint(QPoint* point, TCanvasItem* item) ;
         
     public slots:
+        void selectAll();
+        void deSelectAll();
+        
         void deleteCurrent();
 
         void updateGUI() {
@@ -126,15 +139,13 @@ class MyCanvasView : public QCanvasView
     signals:
         void selectionChanged();
         void movedSomething();
-        void doubleClickedItem( QCanvasItem* );
-        void showContextMenu( QCanvasItem*, QPoint );
+        void doubleClickedItem( TCanvasItem* );
+        void showContextMenu( QPoint );
         
     private:
         void setSelected( QCanvasItem* item = 0, bool control = false );
         KMacroCommand* getMoveCommand();
         
-        QCanvasItemList getSelected();
-
         Definition* def;
 
         KRuler* rulerv;
