@@ -30,9 +30,11 @@
 #include <qsqlcursor.h>
 
 // KDE includes
+#include <kabc/addresseedialog.h>
 #include <kapplication.h>
 #include <kcombobox.h>
 #include <kconfig.h>
+#include <kiconloader.h>
 #include <klineedit.h>
 #include <klocale.h>
 #include <knuminput.h>
@@ -44,7 +46,7 @@ QString PreviewDialog::group = "";
 QString PreviewDialog::article = "";
         
 PreviewDialog::PreviewDialog( QIODevice* device, Definition* d, QString filename, QWidget *parent, const char *name )
-    : QDialog( parent, name,true,WDestructiveClose )
+    : QDialog( parent, name, true, WDestructiveClose )
 {
     file = device;
     def = d;
@@ -81,9 +83,15 @@ PreviewDialog::PreviewDialog( QIODevice* device, Definition* d, QString filename
     serialInc = new KIntNumInput( this );
     serialInc->setRange( 1, 10000, 1, false );
 
+    lineAddr = new KLineEdit( this );
+    lineAddr->setReadOnly( true );
+    
+    buttonAddr = new KPushButton( i18n("Select &Address"), this );
+
     buttonUpdate = new KPushButton( i18n("&Update"), this );
     buttonClose = new KPushButton( i18n("&Close"), this );
-
+    buttonClose->setIconSet( SmallIconSet("fileclose") );
+    
     grid->addWidget( new QLabel( i18n("Customer Name and No.:"), this ), 0, 0 );
     grid->addWidget( customerName, 0, 1 );
     grid->addWidget( customerId, 0, 2 );
@@ -97,13 +105,15 @@ PreviewDialog::PreviewDialog( QIODevice* device, Definition* d, QString filename
     grid->addMultiCellWidget( serialStart, 4, 4, 1, 2 );
     grid->addWidget( new QLabel( i18n( "Serial increment:" ), this ), 5, 0 );
     grid->addMultiCellWidget( serialInc, 5, 5, 1, 2 );
+    grid->addWidget( new QLabel( i18n( "Addressbook entry:" ), this ), 6, 0 );
+    grid->addWidget( lineAddr, 6, 1 );
+    grid->addWidget( buttonAddr, 6, 2 );
     QScrollView* sv = new QScrollView( this );
 
     preview = new QLabel( sv->viewport() );
     sv->addChild( preview );
     
-    Measurements* m = d->getMeasurements();
-    QPixmap pix( (int)m->width( this ), (int)m->height( this ) );
+    QPixmap pix( (int)d->getMeasurements().width( this ), (int)d->getMeasurements().height( this ) );
     pix.fill( Qt::white );
     preview->setPixmap( pix );
         
@@ -118,7 +128,7 @@ PreviewDialog::PreviewDialog( QIODevice* device, Definition* d, QString filename
     Layout->addLayout( buttons );
 
     connect( buttonClose, SIGNAL( clicked() ), this, SLOT( reject() ) );
-
+    connect( buttonAddr, SIGNAL( clicked() ), this, SLOT( selectAddress() ) );
     // TODO:
     // remove this ugly hack! The finished label is only shown when I call
     // updateChanges() twice. I have no idea why!
@@ -161,10 +171,18 @@ void PreviewDialog::setupSql()
     customerName->setCurrentItem( customer_index );
 }
 
+void PreviewDialog::selectAddress()
+{
+    m_address = KABC::AddresseeDialog::getAddressee( this );
+    if( !m_address.isEmpty() ) 
+        lineAddr->setText( m_address.realName() );
+    else
+        lineAddr->setText( QString::null );
+}
+
 void PreviewDialog::updatechanges()
 {
-    Measurements* m = def->getMeasurements();
-    QPixmap pix( (int)m->width( this ), (int)m->height( this ) );
+    QPixmap pix( (int)def->getMeasurements().width( this ), (int)def->getMeasurements().height( this ) );
     pix.fill( Qt::white );
 
     QPainter painter( &pix );
@@ -173,9 +191,8 @@ void PreviewDialog::updatechanges()
         customerId->currentText(), articleId->text(), groupName->text() );
     l->setIndex( spinIndex->value() - 1 );
     l->setSerial( serialStart->text(), serialInc->value() );
-    QPicture* p = l->picture();
-    painter.drawPicture( 0, 0, *p );
-    painter.end();
+    l->setAddressee( &m_address );
+    l->draw( &painter, 0, 0 );
 
     preview->setPixmap( pix );
 
@@ -198,3 +215,5 @@ void PreviewDialog::customerNameChanged( int index )
 {
     customerId->setCurrentItem( index );
 }
+
+#include "previewdialog.moc"
