@@ -76,7 +76,7 @@ SqlTables::SqlTables( QObject* parent )
     drivers.insert( "QMYSQL3", new MySqlDescription() );
     drivers.insert( "QPSQL7", new PostgreSQLDescription() );
     /* The same driver plugin is used for QDBC and SQLite */
-    drivers.insert( "sqlite", new SQLiteDescription() );
+    drivers.insert( "QSQLITE", new SQLiteDescription() );
     drivers.insert( "QODBC3", new SQLiteDescription() );
 
     db = NULL;
@@ -143,7 +143,7 @@ bool SqlTables::newTables( const QString & username, const QString & password, c
 
     if( !drivers[driver] )
         return false;
-	
+
     QSqlDatabase*dbase = QSqlDatabase::addDatabase(driver, drivers[driver]->initdb( database ) );
     dbase->setDatabaseName( drivers[driver]->initdb( database ) );
     dbase->setUserName( username );
@@ -152,18 +152,21 @@ bool SqlTables::newTables( const QString & username, const QString & password, c
 
     if(dbase->open()) {
 
-        bool found = false;
-        QSqlQuery existing("SHOW DATABASES LIKE '" + database + "';");
-        while( existing.next() )
-            found = true;
+        if (driver != "QSQLITE")
+        {
+            bool found = false;
+            QSqlQuery existing("SHOW DATABASES LIKE '" + database + "';");
+            while( existing.next() )
+                found = true;
 
-        QSqlQuery firstquery( NULL, dbase );
-        if( !found && !firstquery.exec("CREATE DATABASE " + database + ";")) {
-            if( KMessageBox::warningContinueCancel( 0, i18n("<qt>Can't create database ")+ database + i18n("<br>You can continue if the database exists already.</qt>")
-                + firstquery.lastError().databaseText() ) == KMessageBox::Cancel ) {
-                dbase->close();
-                QSqlDatabase::removeDatabase(drivers[driver]->initdb( database ));
-                return false;
+            QSqlQuery firstquery( NULL, dbase );
+            if( !found && !firstquery.exec("CREATE DATABASE " + database + ";")) {
+                if( KMessageBox::warningContinueCancel( 0, i18n("<qt>Can't create database ")+ database + i18n("<br>You can continue if the database exists already.</qt>")
+                    + firstquery.lastError().databaseText() ) == KMessageBox::Cancel ) {
+                    dbase->close();
+                    QSqlDatabase::removeDatabase(drivers[driver]->initdb( database ));
+                    return false;
+                }
             }
         }
         dbase->close();
