@@ -26,11 +26,7 @@ class KSpellConfig;
 class KComboBox;
 class TokenProvider;
 
-#if QT_VERSION >= 0x030100
-    class KLineEdit;
-#else
-    class QLineEdit;
-#endif
+class KLineEdit;
 
 class TextLineEditor : public QWidget {
     Q_OBJECT
@@ -58,11 +54,7 @@ class TextLineEditor : public QWidget {
     protected:
         TokenProvider* m_token;
 
-#if QT_VERSION >= 0x030100
         KLineEdit* editor;
-#else
-        QLineEdit* editor;
-#endif
         
         KActionCollection* ac;
         
