@@ -915,10 +915,10 @@ const QString TokenProvider::createSerial()
 QString TokenProvider::unescapeText( const QString & t )
 {
     QString tmp = t;
-    tmp = tmp.replace( DSREPLACE( "&lt;" ), "<" );
-    tmp = tmp.replace( DSREPLACE( "&gt;" ), ">" );
-    tmp = tmp.replace( DSREPLACE( "&amp;" ), "&" );
-    tmp = tmp.replace( DSREPLACE( "&quot;" ), "\"" );
+    tmp = tmp.replace( "&lt;", "<" );
+    tmp = tmp.replace( "&gt;", ">" );
+    tmp = tmp.replace( "&amp;", "&" );
+    tmp = tmp.replace( "&quot;", "\"" );
 
     return tmp;
 }
@@ -926,11 +926,11 @@ QString TokenProvider::unescapeText( const QString & t )
 QString TokenProvider::escapeText( const QString & t )
 {
     QString tmp = t;
-    tmp = tmp.replace( DSREPLACE( "<" ), "&lt;" );
-    tmp = tmp.replace( DSREPLACE( ">" ), "&gt;" );
-    tmp = tmp.replace( DSREPLACE( "&" ), "&amp;"  );
-    tmp = tmp.replace( DSREPLACE( "\"" ), "&quot;" );
-    tmp = tmp.replace( DSREPLACE( "\n" ), "<br />" );
+    tmp = tmp.replace("<", "&lt;" );
+    tmp = tmp.replace(">", "&gt;" );
+    tmp = tmp.replace("&", "&amp;"  );
+    tmp = tmp.replace("\"", "&quot;" );
+    tmp = tmp.replace("\n", "<br />" );
 
     return tmp;
 }
